import {
    processVoiceFromStream,
} from "./audio_handler.js"

import {
    voiceTouchUpEnable,
    voiceTouchUpDisable,
    applyNewGainClarity,
    applyNewGainFullness,
    updateNoiseSuppressionState,
    featureStates,
    setSpatialNodeListenerPosition2D
} from "./conductor.js"

exports.printMsg = function() {
    console.log("This is a message from the sharpi package");
  }

/**
 * This method cleans up a mediastream according to the features configured in the variable "sharpiFeatureStates".
 * 
 * @param {*} stream Your mediastream audio track that needs a cleanup.
 * @returns Cleaned up mediastream.
 */
export function sharpiCleanUpVoice(stream) {


    return processVoiceFromStream(stream)

}

/**
 * This object contains the different features provided by the sharpi app.
 * @object voiceTouchUp - Chooses if the stream needs to be touched up. If that is the case, the touch up happens by setting clarity and fullness of the voice.
 * @object suppressNoise - Chooses if the noise needs to be suppressed or not.
 * 
 */
export let sharpiFeatureStates = {

    /**
     * neural network noise suppresison.
     * @method enable - default true 
     */
     suppressNoise: {
         /**
     * neural network noise suppresison.
     * @param {bool} bool - default true 
     */
        enable: function(bool) {
        updateNoiseSuppressionState(bool)
     },
    
    
    /**
         * get state of whether noise suppression is active or not
         * @param {bool} bool - default true 
         */
            getState: function() { 
                return featureStates.suppressNoise 
            },

        },




    /**  
     * AI-based virtual audio engineer monitors voice characteristics and dynamically adapts audio processing.
     * Processing is applied in the "cleanUpMyVoice" method. 
     * Values for "clarity" and "fullness" depend on user preferences.
     * @method enable - Enables or disables the touch up of the voice.
     * @method clarity - This function sets the clarity of the voice depending on the given input.
     * @method fullness - This function sets the clarity of the voice depending on the given input.
     * 
     */
    voiceTouchUp: {
        /**  
         * 
         * @param {bool} bool Enables or disables the voice touch-up. Default is false.
         */
        enable: function(bool) {
            if (bool)
                voiceTouchUpEnable(),
                featureStates.voiceTouchUp = true
            else
                voiceTouchUpDisable(),
                featureStates.voiceTouchUp = false

        },
        /**
         * sets the clarity of the voice.
         * @param {double} value [0:20] 0 is neutral, 20 is max clarity. Value depends on user preference.
         */
        clarity: function(value) { applyNewGainClarity(value) },

        /**
         * Sets the fullness of the voice.
         * @param {double} value [0:20] 0 is neutral, 20 is max clarity. Value depends on user preference.
         */
        fullness: function(value) { applyNewGainFullness(value) }
    },


    /**  
     * True spatial audio.
     * @method enable - Enables or disables true spatial audio.
     * @method posX - explanation.
     * @method posY - explanation.
     * 
     */
     trueSpatial: {
        /**  
         * 
         * @param {bool} bool Enables or disables the voice touch-up. Default is false.
         */
        enable: function(bool) {
            if (bool)
                voiceTouchUpEnable(),
                featureStates.spatialAudio = true
            else
                voiceTouchUpDisable(),
                featureStates.spatialAudio = false

        },
        /**
         * update position
         * @param {double} value [0:20] 0 is neutral, 20 is max clarity. Value depends on user preference.
         */
        updatePosition: function(posX, posY) { setSpatialNodeListenerPosition2D(posX, posY) }

    }

    
}